fnss.netconfig.nodeconfig.get_application_properties — FNSS 0.7.0 documentation

# fnss.netconfig.nodeconfig.get_application_properties

`get_application_properties`(topology, node, name)

  Return a dictionary containing all the properties of an application deployed on a node

  Parameters: | topology : Topology The topology node : any hashable type The ID of the node name : str The name of the application
  Returns: | applications : dict A dictionary containing the properties of the application